@@ -1,7 +1,10 @@
+from datetime import datetime
 import fnmatch
 from ftplib import FTP
 import logging
 import os
+
+import pytz
 from vlcishared.utils.interfaces import ConnectionInterface
 
 
@@ -47,12 +50,14 @@ class FTPClient(ConnectionInterface):
         matching_files = fnmatch.filter(remote_files, pattern)
         return matching_files
 
-    def download(self, remote_path: str, local_path: str, pattern: str):
+    def download(self, remote_path: str, local_path: str, pattern: str, min_date: datetime = None):
         """
-        Descarga uno o varios archivos del servidor FTP al directorio local que cumplan con el patrón especificado.
+        Descarga uno o varios archivos del servidor FTP al directorio local que cumplan con el patrón especificado
+        y cuya fecha de modificación sea mayor a min_date (si se indica).
         - remote_path: ruta en el servidor FTP
         - local_path: directorio en local
         - pattern: patrón estilo shell (ej: '*.csv')
+        - min_date: fecha de modificación mínima
         """
         try:
             matching_files = self.list_matching_files(remote_path, pattern)
@@ -60,9 +65,22 @@ class FTPClient(ConnectionInterface):
                 raise FileNotFoundError(f"No se encontraron archivos que cumplan el patrón '{pattern}' en {remote_path}")
 
             for remote_file in matching_files:
+                if min_date:
+                    resp = self.ftp.sendcmd(f"MDTM {remote_file}")
+                    fecha_str = resp.split()[1]
+                    fecha_mod = datetime.strptime(fecha_str, "%Y%m%d%H%M%S")  # datetime naive
+                    fecha_mod = fecha_mod.replace(tzinfo=pytz.UTC)
+
+                    if fecha_mod <= min_date:
+                        self.log.info(f"Saltando {remote_file}, fecha modificación: {fecha_mod} <= {min_date}")
+                        continue
+
                 local_file = os.path.join(local_path, os.path.basename(remote_file))
                 with open(local_file, "wb") as file:
                     self.ftp.retrbinary(f"RETR {remote_file}", file.write)
+                self.log.info(f"Descargado {remote_file} -> {local_file}")
+        except FileNotFoundError:
+            raise
         except Exception as e:
             raise ConnectionAbortedError(f"Descarga fallida: {str(e)}")
 
@@ -82,7 +100,7 @@ class FTPClient(ConnectionInterface):
                 self.ftp.storbinary(f"STOR {remote_path}", file)
         except Exception as e:
             raise ConnectionAbortedError(f"Subida fallida: {str(e)}")
-        
+
     def execute_with_connection(self, method, *args, **kwargs):
         self.connect()
         try:
