@@ -1,5 +1,9 @@
+from datetime import datetime
+import logging
 import re
 
+import pytz
+
 import paramiko
 
 from vlcishared.utils.interfaces import ConnectionInterface
@@ -17,6 +21,7 @@ class SFTPClient(ConnectionInterface):
         self.password = password
         self.transport = None
         self.sftp = None
+        self.log = logging.getLogger(__name__)
 
     def connect(self) -> None:
         """Intenta conectarse al servidor configurado en la instanciación"""
@@ -27,8 +32,9 @@ class SFTPClient(ConnectionInterface):
         except Exception as e:
             raise ConnectionRefusedError(f"Conexión fallida: {str(e)}")
 
-    def download(self, remote_path: str, local_path: str, pattern: str):
-        '''Descarga en local los ficheros del directorio remoto que coincidan con el patrón indicado"'''
+    def download(self, remote_path: str, local_path: str, pattern: str, min_date: datetime = None):
+        """Descarga en local los ficheros del directorio remoto que coincidan con el patrón indicado
+        y cuya fecha de modificación sea mayor a min_date (si se indica)."""
         try:
             file_list = self.list_matching_files(remote_path, pattern)
 
@@ -36,9 +42,19 @@ class SFTPClient(ConnectionInterface):
                 raise FileNotFoundError(f"No se encontraron archivos que cumplan el patrón '{pattern}' en {remote_path}")
 
             for file_name in file_list:
+                if min_date:
+                    attr = self.sftp.stat(f"{remote_path}/{file_name}")
+                    file_mtime = datetime.fromtimestamp(attr.st_mtime, pytz.UTC)
+                    if file_mtime <= min_date:
+                        self.log.info(f"Saltando {file_name}, fecha modificación: {file_mtime} <= {min_date}")
+                        continue
+
                 self.sftp.get(f"{remote_path}/{file_name}", f"{local_path}/{file_name}")
-        except Exception:
+                self.log.info(f"Descargado {file_name} -> {local_path}/{file_name}")
+        except FileNotFoundError:
             raise
+        except Exception as e:
+            raise ConnectionAbortedError(f"Descarga fallida: {str(e)}")
 
     def list_matching_files(self, remote_path: str, pattern: str) -> list:
         """Devuelve una lista de ficheros en el directorio indicado que coincidan con el patrón indicado."""
