@@ -52,9 +52,7 @@ def mock_postgres_patch(monkeypatch, db_transaction):
             db_transaction
         )
         mock_connector.insert_many_rows.side_effect = insert_many_rows_side_effect or insert_many_rows_side_effect_default(db_transaction)
-        mock_connector.engine = db_transaction
-
-        mock_connector.engine = db_transaction
+        mock_connector.engine = db_transaction.engine
 
         # @contextmanager te envuelve esa función en un objeto que implementa __enter__ y __exit__
         # sirve para cuando en la ETL hacemos with PostgresConnector.instance().engine.begin as conn:
