@@ -1,8 +1,11 @@
+from datetime import datetime
 import os
 import re
 import shutil
 from unittest.mock import MagicMock
 
+import pytz
+
 import pytest
 
 from vlcishared.sftp.sftp import SFTPClient
@@ -78,7 +81,9 @@ def mock_sftp_patch(monkeypatch):
         if list_sorted_date_modification_side_effect:
             sftp_mock.list_sorted_date_modification.side_effect = list_sorted_date_modification_side_effect
 
-        sftp_mock.download.side_effect = lambda remote_path, local_path, pattern: download_side_effect(sftp_mock, remote_path, local_path, pattern)
+        sftp_mock.download.side_effect = lambda remote_path, local_path, pattern, min_date=None: download_side_effect(
+            sftp_mock, remote_path, local_path, pattern, min_date
+        )
         sftp_mock.move.side_effect = move_side_effect
         sftp_mock.upload.side_effect = upload_side_effect
         sftp_mock.delete.side_effect = delete_side_effect
@@ -115,7 +120,7 @@ def patch_list_all_files_side_effect(directorio):
     return os.listdir(directorio)
 
 
-def patch_download_side_effect(self, remote_path, local_path, pattern):
+def patch_download_side_effect(self, remote_path, local_path, pattern, min_date=None):
     """
     Simula la descarga de archivos desde remote_path a local_path,
     filtrando por patrón regex y copiando los archivos locales que coincidan.
@@ -125,6 +130,13 @@ def patch_download_side_effect(self, remote_path, local_path, pattern):
     for archivo in matching_files:
         origen = os.path.join(remote_path, archivo)
         destino = os.path.join(local_path, archivo)
+
+        fecha_mod = datetime.fromtimestamp(os.path.getmtime(origen), pytz.UTC)
+
+        # Filtrar por min_date si se proporciona
+        if min_date and fecha_mod <= min_date:
+            continue
+
         shutil.copyfile(origen, destino)
 
 
