@@ -30,7 +30,8 @@ def mock_http_patch(monkeypatch):
         get_side_effect=None,
         post_side_effect=None,
         post_con_reintentos_side_effect=None,
-        descargar_archivo_side_effect=None,
+        descargar_archivo_get_side_effect=None,
+        descargar_archivo_post_side_effect=None,
     ):
         http = MagicMock()
         http.cerrar.return_value = None
@@ -38,7 +39,12 @@ def mock_http_patch(monkeypatch):
         http.get.side_effect = get_side_effect
         http.post.side_effect = post_side_effect
         http.post_con_reintentos.side_effect = post_con_reintentos_side_effect
-        http.descargar_archivo.side_effect = descargar_archivo_side_effect or patch_descargar_archivo_side_effect
+        http.descargar_archivo_get.side_effect = (
+            descargar_archivo_get_side_effect or patch_descargar_archivo_get_side_effect
+        )
+        http.descargar_archivo_post.side_effect = (
+            descargar_archivo_post_side_effect or patch_descargar_archivo_post_side_effect()
+        )
 
         monkeypatch.setattr(ruta_importacion, lambda *args, **kwargs: http)
         return http
@@ -46,9 +52,23 @@ def mock_http_patch(monkeypatch):
     return _patch
 
 
-def patch_descargar_archivo_side_effect(url, destino):
+def patch_descargar_archivo_get_side_effect(url, destino):
     """
     Simula la descarga de un archivo desde HTTP copiándolo desde 'url' a 'destino'.
     """
     shutil.copyfile(url, destino)
     return True
+
+def patch_descargar_archivo_post_side_effect(contenido_salida: str = "<Respuesta><Ok>True</Ok></Respuesta>"):
+    """
+    Devuelve una función side effect que escribe 'contenido_salida' en el archivo destino.
+    Esto permite parametrizar el contenido fácilmente en los tests.
+    """
+
+    def _inner(url_origen, destino, url_headers, url_body):
+        os.makedirs(os.path.dirname(destino), exist_ok=True)
+        with open(destino, "w", encoding="utf-8") as f:
+            f.write(contenido_salida)
+        return True
+
+    return _inner
