@@ -1,11 +1,7 @@
 from pandas import DataFrame
 
 
-CARACTERES_PROHIBIDOS_CONTEXT_BROKER = {
-    '>': '[', '<': ']', '‘': '´', '“': '´',
-    '=': '-', ';': ',', '(': '[', ')': ']',
-    "'": '´',
-}
+CARACTERES_PROHIBIDOS_CONTEXT_BROKER = {">": "[", "<": "]", "‘": "´", "“": "´", "=": "-", ";": ",", "(": "[", ")": "]", "'": "´", '"': "´"}
 
 
 def reemplazar_caracteres_prohibidos_context_broker(df: DataFrame) -> DataFrame:
